@@ -167,7 +167,7 @@ OC.L10N.register(
     "Edit" : "Upravit",
     "Add a new tag" : "Přidat nový štítek",
     "title and color value must be provided" : "je třeba zadat nadpis a zvolit barvu",
-    "Title" : "Nadpis",
+    "Board name" : "Název tabule",
     "Members" : "Členové",
     "Upload attachment" : "Nahrát přílohu",
     "Add this attachment" : "Přidat tuto přílohu",
@@ -202,6 +202,7 @@ OC.L10N.register(
     "Edit description" : "Upravit popis",
     "View description" : "Zobrazit popis",
     "Add Attachment" : "Přidat přílohu",
+    "Write a description …" : "Zadejte popis…",
     "Choose attachment" : "Zvolte přílohu",
     "(group)" : "(skupina)",
     "(circle)" : "(okruh)",
@@ -218,14 +219,24 @@ OC.L10N.register(
     "All boards" : "Všechny tabule",
     "Archived boards" : "Archivované tabule",
     "Shared with you" : "Sdíleno s vámi",
-    "Use modal card view" : "Použít modální zobrazení karty",
     "Show boards in calendar/tasks" : "Zobrazit tabule v kalendáři/úkolech",
     "Limit deck usage of groups" : "Omezit využití deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny.",
-    "Board name" : "Název tabule",
     "Board details" : "Podrobnosti o desce",
     "Edit board" : "Upravit tabuli",
+    "Clone board" : "Klonovat tabuli",
+    "Unarchive board" : "Vrátit tabuli zpět z archivu",
+    "Archive board" : "Archivovat tabuli",
+    "Turn on due date reminders" : "Zapnout upomínky termínů",
+    "Turn off due date reminders" : "Vypnout upomínky termínů",
+    "Due date reminders" : "Upomínky termínů",
+    "All cards" : "Všechny karty",
+    "Assigned cards" : "Přiřazené karty",
+    "No notifications" : "Žádná upozornění",
+    "Delete board" : "Smazat tabuli",
     "Board {0} deleted" : "Tabule {0} smazána",
+    "Only assigned cards" : "Pouze přiřazené karty",
+    "No reminder" : "Bez připomínky",
     "An error occurred" : "Došlo k chybě",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Opravdu chcete tabuly {title} smazat? Toto smaže veškerá data této tabule.",
     "Delete the board?" : "Smazat tabuli?",
