@@ -14,6 +14,9 @@ OC.L10N.register(
     "copy" : "복사",
     "To do" : "할 일",
     "Done" : "완료",
+    "Example Task 3" : "작업 예제 3",
+    "Example Task 2" : "작업 예제 2",
+    "Example Task 1" : "작업 예제 1",
     "The file was uploaded" : "파일을 업로드함",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
@@ -64,7 +67,6 @@ OC.L10N.register(
     "Delete list" : "목록 지우기",
     "Add card" : "카드 추가",
     "Edit" : "편집",
-    "Title" : "직위",
     "Members" : "구성원",
     "Upload attachment" : "첨부 파일 업로드",
     "Attachments" : "첨부파일",
