@@ -160,12 +160,13 @@ OC.L10N.register(
     "Edit" : "Taisyti",
     "Add a new tag" : "Pridėti naują žymę",
     "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
-    "Title" : "Pavadinimas",
+    "Board name" : "Lentos pavadinimas",
     "Members" : "Nariai",
     "Upload attachment" : "Įkelti priedą",
     "Add this attachment" : "Pridėti šį priedą",
     "Delete Attachment" : "Ištrinti priedą",
     "Restore Attachment" : "Atkurti priedą",
+    "Open in bigger view" : "Atverti didesniame rodinyje",
     "Attachments" : "Priedai",
     "Comments" : "Komentarai",
     "Modified" : "Pakeistas",
@@ -207,10 +208,17 @@ OC.L10N.register(
     "Archived boards" : "Archyvuotos lentos",
     "Shared with you" : "Bendrinama su jumis",
     "Show boards in calendar/tasks" : "Rodyti darbus kalendoriuje/užduotyse",
-    "Board name" : "Lentos pavadinimas",
     "Board details" : "Išsamiau apie lentą",
     "Edit board" : "Taisyti lentą",
+    "Turn on due date reminders" : "Įjungti galutinio termino priminimus",
+    "Turn off due date reminders" : "Išjungti galutinio termino priminimus",
+    "Due date reminders" : "Galutinio termino priminimai",
+    "All cards" : "Visos kortelės",
+    "Assigned cards" : "Priskirtos kortelės",
+    "No notifications" : "Pranešimų nėra",
+    "Delete board" : "Ištrinti lentą",
     "Board {0} deleted" : "Lenta {0} ištrinta",
+    "Only assigned cards" : "Tik priskirtos kortelės",
     "An error occurred" : "Įvyko klaida",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Ar tikrai norite ištrinti lentą, pavadinimu {title}? Tai ištrins visus šios lentos duomenis.",
     "Delete the board?" : "Ištrinti lentą?",
