@@ -167,7 +167,7 @@ OC.L10N.register(
     "Edit" : "Redigera",
     "Add a new tag" : "Lägg till en ny tagg",
     "title and color value must be provided" : "titel och färg måste anges",
-    "Title" : "Titel",
+    "Board name" : "Tavlans namn",
     "Members" : "Medlemmar",
     "Upload attachment" : "Ladda upp bilaga",
     "Add this attachment" : "Lägg till denna bilaga",
@@ -219,11 +219,9 @@ OC.L10N.register(
     "All boards" : "Alla tavlor",
     "Archived boards" : "Arkiverade tavlor",
     "Shared with you" : "Delad med dig",
-    "Use modal card view" : "Använd modal kort-vy",
     "Show boards in calendar/tasks" : "Visa tavlor i kalender / uppgifter",
     "Limit deck usage of groups" : "Begränsa användningen av grupper",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Begränsa Deck blockerar användare som inte ingår i dessa grupper från att skapa egna tavlor. Användare kan fortfarande arbeta med tavlor som har delats med dem.",
-    "Board name" : "Tavlans namn",
     "Board details" : "Taveldetaljer",
     "Edit board" : "Ändra tavla",
     "Clone board" : "Kopiera tavla",
