@@ -45,6 +45,7 @@ OC.L10N.register(
     "Deck" : "看板",
     "Changes in the <strong>Deck app</strong>" : "<strong>看板应用</strong>中的改变",
     "A <strong>comment</strong> was created on a card" : "卡片上创建了一个 <strong>评论</strong>",
+    "Upcoming cards" : "即将到来的卡片",
     "Personal" : "个人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "%s已给您指派\"%s\" 中的卡片\"%s\"。",
     "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} 已给您指派\"%s\" 中的卡片\"%s\"。",
@@ -112,6 +113,8 @@ OC.L10N.register(
     "Toggle compact mode" : "切换简洁模式",
     "Details" : "详情",
     "Loading board" : "正在加载面板",
+    "No lists available" : "无列表可用",
+    "Create a new list to add cards to this board" : "创建一个新列表来添加卡片到这个看板",
     "Board not found" : "未找到面板",
     "Sharing" : "正在共享",
     "Tags" : "标签",
@@ -121,6 +124,7 @@ OC.L10N.register(
     "Undo" : "撤消",
     "Deleted cards" : "已删除卡片",
     "Share board with a user, group or circle …" : "与一个用户，群组或圈子共享面板...",
+    "Searching for users, groups and circles …" : "正在搜索用户、群组和圈子 ......",
     "No participants found" : "未找到参与者",
     "Board owner" : "面板拥有者",
     "(Group)" : "（群组）",
@@ -129,23 +133,31 @@ OC.L10N.register(
     "Can share" : "可以共享",
     "Can manage" : "可以管理",
     "Delete" : "删除",
+    "Failed to create share with {displayName}" : "用 {displayName} 创建分享失败",
+    "Add a new list" : "添加一个新列表",
     "Archive all cards" : "存档所有卡片",
     "Delete list" : "删除列表",
     "Add card" : "添加卡片",
+    "Archive all cards in this list" : "存档该列表的所有卡片",
     "Add a new card" : "添加一张新卡片",
+    "Card name" : "卡片名",
+    "List deleted" : "列表被删除",
     "Edit" : "编辑",
     "Add a new tag" : "新增一个标签",
     "title and color value must be provided" : "必须提供标题和颜色值",
-    "Title" : "标题",
+    "Board name" : "看板名",
     "Members" : "会员",
     "Upload attachment" : "上传附件",
     "Add this attachment" : "添加此附件",
     "Delete Attachment" : "删除附件",
     "Restore Attachment" : "恢复附件",
+    "Open in sidebar view" : "在侧边栏视图中打开",
+    "Open in bigger view" : "在较大视图中打开",
     "Attachments" : "附件",
     "Comments" : "评论",
     "Modified" : "已修改",
     "Created" : "已创建",
+    "The title cannot be empty." : "标题不能为空",
     "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
     "Assign a tag to this card…" : "为该卡片分配标签…",
     "Assign to users" : "指派给用户",
@@ -168,33 +180,56 @@ OC.L10N.register(
     "Edit description" : "编辑描述",
     "View description" : "查看描述",
     "Add Attachment" : "添加附件",
+    "Write a description …" : "写一段描述",
     "Choose attachment" : "选择附件",
     "(group)" : "（组）",
     "(circle)" : "（圈子）",
     "Assign to me" : "指派给我",
+    "Unassign myself" : "自己解除分配",
     "Move card" : "移动卡片",
     "Unarchive card" : "恢复卡片存档",
     "Archive card" : "归档卡片",
     "Delete card" : "删除卡片",
     "Move card to another board" : "将卡片移到其他面板",
+    "Select a list" : "选择一个列表",
+    "Card deleted" : "卡片被删除",
     "seconds ago" : "几秒前",
     "All boards" : "全部面板",
     "Archived boards" : "已归档面板",
     "Shared with you" : "收到的共享",
+    "Use bigger card view" : "使用较大的卡片视图",
+    "Show boards in calendar/tasks" : "在日历/任务中显示看板",
     "Limit deck usage of groups" : "限制群组的看板使用",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "非面板创建用户组的用户将不能使用受限看板。但用户仍然能够使用已共享给他们的面板工作。",
     "Board details" : "面板详情",
     "Edit board" : "编辑面板",
+    "Clone board" : "克隆看板",
+    "Unarchive board" : "取消对看板的存档",
+    "Archive board" : "存档看板",
+    "Turn on due date reminders" : "打开到期日期提醒 ",
+    "Turn off due date reminders" : "关闭到期日提醒",
+    "Due date reminders" : "到期日期提醒",
+    "All cards" : "所有卡片",
+    "Assigned cards" : "分配的卡片",
+    "No notifications" : "无通知",
+    "Delete board" : "删除看板",
     "Board {0} deleted" : "面板{0} 被删除",
+    "Only assigned cards" : "仅分配的卡片",
+    "No reminder" : "无提醒",
     "An error occurred" : "发生错误",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你确定你要删除 {title}面板吗？面板内所有数据都将因此被删除。",
     "Delete the board?" : "是否删除面板？",
+    "Loading filtered view" : "正在加载已过滤视图",
     "Today" : "今天",
     "Tomorrow" : "明天",
     "This week" : "本周",
+    "No due" : "没有到期的",
+    "No upcoming cards" : "没有即将到来的卡片",
+    "upcoming cards" : "即将到来的卡片",
     "Link to a board" : "链接到一个面板",
     "Link to a card" : "链接到一张卡片",
     "Something went wrong" : "有地方出错了",
+    "Failed to upload {name}" : "未能上传 {name}",
     "Maximum file size of {size} exceeded" : "文件大小 {size} 超出最大限制"
 },
 "nplurals=1; plural=0;");
